<!DOCTYPE html><html lang="en"><!-- Mirrored from html.kodesolution.com/2023/satnet-html/index-4-dark.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:18 GMT --><head>
<meta charset="utf-8">
<title>Satnet | Broadband HTML Template | Home Page Dark 04</title>
<!-- Stylesheets -->
<link href="css/animate.css" rel="stylesheet">
<link href="css/bootstrap.min.css" rel="stylesheet">
<link href="css/slick.css" rel="stylesheet">
<link href="css/slick-theme.css" rel="stylesheet">
<link href="css/select2.min.css" rel="stylesheet">
<link href="css/swipebox.min.css" rel="stylesheet">
<link href="css/swiper-bundle.min.css" rel="stylesheet">
<link href="css/style.css" rel="stylesheet">
<link href="css/style-dark.css" rel="stylesheet">

<link rel="shortcut icon" href="images/favicon2.png" type="image/x-icon">
<link rel="icon" href="images/favicon2.png" type="image/x-icon">

<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">
<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
<link rel="stylesheet" href="css/custom_elements.css?0iWSiOes" id="custom-elements-css"><link rel="stylesheet" href="css/code_editor_styles.css?S4b0DqEk" id="custom-css"><link rel="stylesheet" href="font-awesome/font-awesome.min.css?zGRwkVnT" id="font-awesome"></head>

<body class="layout2">

<div class="page-wrapper">
	
    <!-- Main Header-->
	<header class="main-header header-style-two">
		<!-- Header Top -->
		<div class="header-top">
			<div class="container">
				<div class="header-top-content">
					<div class="top-left">
						<!-- Info List -->
                        <ul class="info-list">
                            <li>
                                <img src="images/icons/header-phone.png" alt="">
                                <span><strong>Phone.</strong>  +88(9800) 6802</span>
                            </li>
                            <li>
                                <img src="images/icons/header-mail.png" alt="">
                                <span><strong>Email.</strong> <a href="https://html.kodesolution.com/cdn-cgi/l/email-protection" class="__cf_email__" data-cfemail="cebbbdabbca0afa3ab8eaaa1a3afa7a0e0ada1a3">[email&nbsp;protected]</a></span>
                            </li>
                        </ul>
					</div>
					<div class="top-right">
						<!-- Header Search -->
						<button class="search-btn">
                            <i class="flaticon-search"></i>
							Search
						</button>
						<button class="login-btn">
                            <i class="flaticon-user"></i>
							Login &amp; Register
						</button>
					</div>
				</div>
			</div>
		</div>
		<!-- Header Top -->

        <div class="header-lower">
            <!-- Main box -->
            <div class="main-box">
                <div class="logo-box">
                    <div class="logo"><a href="index.html"><img src="images/logo-v2-white.png" alt="" title="Satnet"></a></div>
                </div>

                <!--Nav Box-->
                <div class="nav-outer">    
                    <nav class="nav main-menu">
                        <ul class="navigation">
                            <li class="current dropdown"><a href="index.html">Home</a>
                                <ul>
                                    <li><a href="index.html">Home page 01</a></li>
                                    <li><a href="index-2.html">Home page 02</a></li>
                                    <li><a href="index-3.html">Home page 03</a></li>
                                    <li><a href="index-4.html">Home page 04</a></li>
                                    <li class="dropdown"><a href="#">Single Styles</a>
                                        <ul>
                                            <li><a href="index-1-single.html">Single Style One</a></li>
                                            <li><a href="index-2-single.html">Single Style Two</a></li>
                                            <li><a href="index-3-single.html">Single Style Two</a></li>
                                            <li><a href="index-4-single.html">Single Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Dark Styles</a>
                                        <ul>
                                            <li><a href="index-1-dark.html">Darl Style One</a></li>
                                            <li><a href="index-2-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-3-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-4-dark.html">Darl Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Header Styles</a>
                                        <ul>
                                            <li><a href="index.html">Header Style One</a></li>
                                            <li><a href="index-2.html">Header Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="index-1-rtl.html">RTL Style One</a></li>
                                </ul>
                            </li>
                            <li class="dropdown"><a href="page-about.html">About</a>
                                <ul>
                                    <li><a href="page-about.html">About</a></li>
                                    <li class="dropdown"><a href="page-team.html">Team</a>
                                        <ul>
                                            <li><a href="page-team.html">Team Grid</a></li>
                                            <li><a href="page-team-details.html">Team Details</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="shop-products.html">Shop</a>
                                        <ul>
                                            <li><a href="shop-products.html">Products</a></li>
                                            <li><a href="shop-products-sidebar.html">Products with Sidebar</a></li>
                                            <li><a href="shop-product-details.html">Product Details</a></li>
                                            <li><a href="shop-cart.html">Cart</a></li>
                                            <li><a href="shop-checkout.html">Checkout</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="page-testimonial.html">Testimonial</a></li>
                                    <li><a href="page-pricing.html">Pricing</a></li>
                                    <li><a href="page-faq.html">FAQ</a></li>
                                    <li><a href="page-404.html">Page 404</a></li>
                                </ul>
                            </li>
                            <li class="dropdown"><a href="page-services.html">Services</a>
                                <ul>
                                    <li><a href="page-services.html">Services Grid</a></li>
                                    <li><a href="page-service-details.html">Service Details</a></li>
                                </ul>
                            </li>
							<li class="dropdown"><a href="page-about.html">Pages</a>
								<ul>
									<li><a href="page-about.html">About</a></li>
									<li><a href="page-movie.html">Movie</a></li>
									<li><a href="page-pricing.html">Pricing</a></li>
									<li class="dropdown"><a href="shop-products.html">Shop</a>
										<ul>
											<li><a href="shop-products.html">Products</a></li>
											<li><a href="shop-products-sidebar.html">Products Sidebar</a></li>
											<li><a href="shop-product-details.html">Product Details</a></li>
											<li><a href="shop-cart.html">Cart</a></li>
											<li><a href="shop-checkout.html">Checkout</a></li>
										</ul>
									</li>
									<li><a href="page-team.html">Team</a></li>
									<li><a href="page-testimonial.html">Testimonial</a></li>
									<li><a href="page-faq.html">FAQ</a></li>
									<li><a href="page-404.html">Page 404</a></li>
								</ul>
							</li>
                            <li class="dropdown"><a href="news-grid.html">News</a>
                                <ul>
                                    <li><a href="news-grid.html">News Grid</a></li>
                                    <li><a href="news-details.html">News Details</a></li>
                                </ul>
                            </li>
                            <li><a href="page-contact.html">Contact</a></li>
                        </ul>
                    </nav>
                    <!-- Main Menu End-->
                </div>

                <div class="outer-box">
                    <div class="mobile-nav-toggler">
                        <span></span>
                        <span></span>
                    </div>
                    <a href="page-contact.html" class="header-btn bg-dark text-white">get started  <span><i class="lnr-icon-arrow-right text-white"></i></span></a>
                    <!-- Mobile Nav toggler -->
                </div>
            </div>
        </div>
		
		<!-- Mobile Menu  -->
		<div class="mobile-menu">
			<div class="menu-backdrop"></div>
		
			<!--Here Menu Will Come Automatically Via Javascript / Same Menu as in Header-->
			<nav class="menu-box">
				<div class="upper-box">
					<div class="nav-logo"><a href="index.html"><img src="images/logo-v2-white.png" alt="" title=""></a></div>
					<div class="close-btn"><i class="icon fa fa-times"></i></div>
				</div>
		
				<ul class="navigation clearfix">
					<!--Keep This Empty / Menu will come through Javascript-->
				</ul>
				<ul class="contact-list-one">
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<i class="icon lnr-icon-phone-handset"></i>
							<span class="title">Call Now</span>
							<a href="tel:+92880098670">+92 (8800) - 98670</a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-envelope1"></span>
							<span class="title">Send Email</span>
							<a href="https://html.kodesolution.com/cdn-cgi/l/email-protection#dfb7bab3af9fbcb0b2afbeb1a6f1bcb0b2"><span class="__cf_email__" data-cfemail="640c01081424070b0914050a1d4a070b09">[email&nbsp;protected]</span></a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-clock"></span>
							<span class="title">Send Email</span>
							Mon - Sat 8:00 - 6:30, Sunday - CLOSED
						</div>
					</li>
				</ul>
		
		
				<ul class="social-links">
					<li><a href="#"><i class="fa fa-x"></i></a></li>
					<li><a href="#"><i class="fab fa-facebook-f"></i></a></li>
					<li><a href="#"><i class="fab fa-pinterest"></i></a></li>
					<li><a href="#"><i class="fab fa-instagram"></i></a></li>
				</ul>
			</nav>
		</div><!-- End Mobile Menu -->

		<!-- Header Search -->
		<div class="search-popup">
			<span class="search-back-drop"></span>
			<button class="close-search"><span class="fa fa-times"></span></button>
		
			<div class="search-inner">
				<form method="post" action="https://html.kodesolution.com/2023/satnet-html/index.html">
					<div class="form-group">
						<input type="search" name="search-field" value="" placeholder="Search..." required="">
						<button type="submit"><i class="fa fa-search"></i></button>
					</div>
				</form>
			</div>
		</div>
		<!-- End Header Search -->

		<!-- Sticky Header  -->
		<div class="sticky-header">
			<div class="auto-container">
				<div class="inner-container">
					<!--Logo-->
					<div class="logo">
						<a href="index.html" title=""><img src="images/logo-v2-white.png" alt="" title=""></a>
					</div>
		
					<!--Right Col-->
					<div class="nav-outer">
						<!-- Main Menu -->
						<nav class="main-menu">
							<div class="navbar-collapse show collapse clearfix">
								<ul class="navigation clearfix">
									<!--Keep This Empty / Menu will come through Javascript-->
								</ul>
							</div>
						</nav><!-- Main Menu End-->
		
						<!--Mobile Navigation Toggler-->
						<div class="mobile-nav-toggler">
                            <span></span>
                            <span></span>
                        </div>
					</div>
				</div>
			</div>
		</div><!-- End Sticky Menu -->
	</header>
	<!--End Main Header -->
    
    <!-- MAIN BANNER SLIDER  -->
    
    <section class="main-slider-v2">
        <div class="banner-slider-v2">
            <div class="banner-slide">
                <img src="images/main-slider/banner1.jpg" alt="">
                <div class="banner-slide-content">
                    <div class="container">
                        <div class="banner-content">
                            <span data-animation-in="fadeInUp" data-delay-in="0.1">Best Internet Enjoy Life</span>
                            <h2 class="title" data-animation-in="fadeInUp" data-delay-in="0.3">Ultimate Control of Your Internet</h2>
                            <p data-animation-in="fadeInUp" data-delay-in="0.5">Can consent to the use of such technologies byclosing this notice senectus amet sodales habitant dapibus</p>
                            <a href="page-about.html" title="" class="theme-btn-v2 bg-btn bg-dark text-white" data-animation-in="fadeInUp" data-delay-in="0.7">check availability</a>
                        </div>
                    </div>
                </div><!--banner-slide-content-->
            </div>
            <div class="banner-slide">
                <img src="images/main-slider/banner1.jpg" alt="">
                <div class="banner-slide-content">
                    <div class="container">
                        <div class="banner-content">
                            <span data-animation-in="fadeInUp" data-delay-in="0.1">Best Internet Enjoy Life</span>
                            <h2 class="title" data-animation-in="fadeInUp" data-delay-in="0.3">Ultimate Control of Your Internet</h2>
                            <p data-animation-in="fadeInUp" data-delay-in="0.5">Can consent to the use of such technologies byclosing this notice senectus amet sodales habitant dapibus</p>
                            <a href="page-about.html" title="" class="theme-btn-v2 bg-btn bg-dark text-white" data-animation-in="fadeInUp" data-delay-in="0.7">check availability</a>
                        </div>
                    </div>
                </div><!--banner-slide-content-->
            </div>
        </div>
    </section>


    <section class="about-section-v2 pb-0">
        <div class="container py-0">
            <div class="row align-items-center">
                <div class="col-lg-6 about-column">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image">
                                <img src="images/resource/about2.png" alt="">
                            </figure>
                            <div class="box-info wow fadeInUp">
                                <h4>50 mbps</h4>
                                <span>download speed test</span>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-lg-6 about-content-column">
                    <div class="inner-column wow fadeInRight">
                        <div class="sec-title-v2">
                            <span class="sub-title border-shape text">Sustainability Is Our Focus</span>
                            <h2>Committed to Building a Better Future </h2>
                        </div>
                        <p class="text">Lorem ipsum dolor sit amet, consectetur adipisicing elit,sed eius to mod tempor incididunt ut labore et dolore magna aliqua. Ut enims ad minim veniam. Aenean massa. Lorem ipsum dolor sit amet,to mod tempor incididunt ut labore et dolore magna aliqua. Ut enims ad minim veniam. Aenean massa.</p>
                        <ul>
                            <li class="text">We have been a climate positive workforce</li>
                            <li class="text">We have been a climate positive workforce</li>
                            <li class="text">We have been a climate positive workforce</li>
                        </ul>
                    </div>
                </div><!--about-content-column-->
            </div>
        </div>
    </section><!--about-section-v2-->

    <section class="what-we-do-section-v2 pt-0">
        <div class="container">
            <div class="row align-items-center">
                <div class="col-lg-6 ">
                    <div class="row">
                        <div class="col-lg-6 col-md-6 col-sm-6 svs-column">
                            <div class="inner-column wow fadeInLeft">
                                <div class="icon-box">
                                    <i class="flaticon-globe"></i>
                                </div>
                                <div class="content-info">
                                    <h4 class="title text-white">Secure Internet</h4>
                                    <p class="text">Lorem ipsum, or lipsum as it is some times known, is dumm</p>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-6 col-sm-6 svs-column">
                            <div class="inner-column wow fadeInLeft" data-wow-delay="200ms">
                                <div class="icon-box">
                                    <i class="flaticon-streaming"></i>
                                </div>
                                <div class="content-info">
                                    <h4 class="title text-white">4K &amp; 8K streaming</h4>
                                    <p class="text">Lorem ipsum, or lipsum as it is some times known, is dumm</p>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-lg-6 svs-video">
                    <div class="image-box wow fadeInRight">
                        <figure class="image">
                            <img src="images/resource/svs-img.jpg" alt="">
                        </figure>
                        <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="play-btn swipebox"><img src="images/icons/play2.png" alt=""></a>
                    </div>
                </div><!--svs-video-->
            </div>
        </div>
    </section><!--what we do end-->

    <!-- SERVICES SECTION -->
    <section class="services-section-v2 py-0">
        <div class="container py-0">
            <div class="sec-title-v2 text-center wow fadeInUp">
                <i class="flaticon-wifi-1 text-white"></i>
                <span class="sub-title text">SUSTAINABILITY IS OUR FOCUS</span>
                <h2>Services Available</h2>
            </div>
            <div class="row">
                <div class="col-lg-3 tabs-column">
                    <div class="inner-column wow fadeInLeft">
                        <ul class="nav nav-tabs" id="myTab" role="tablist">
                            <li class="nav-item" role="presentation">
                              <button class="nav-link active" id="home-tab" data-bs-toggle="tab" data-bs-target="#home" type="button" role="tab" aria-controls="home" aria-selected="true">
                                <i class="flaticon-wireless-internet"></i>
                                <span>Compare Broadband</span>
                              </button>
                            </li>
                            <li class="nav-item" role="presentation">
                              <button class="nav-link" id="profile-tab" data-bs-toggle="tab" data-bs-target="#profile" type="button" role="tab" aria-controls="profile" aria-selected="false">
                                <i class="flaticon-speedometer"></i>
                                <span>Compare Energy</span>
                              </button>
                            </li>
                            <li class="nav-item" role="presentation">
                              <button class="nav-link" id="contact-tab" data-bs-toggle="tab" data-bs-target="#contact" type="button" role="tab" aria-controls="contact" aria-selected="false">
                                <i class="flaticon-speedometer"></i>
                                <span>WiFi router and TV Box </span>
                              </button>
                            </li>
                            <li class="nav-item" role="presentation">
                                <button class="nav-link" id="contact2-tab" data-bs-toggle="tab" data-bs-target="#contact2" type="button" role="tab" aria-controls="contact2" aria-selected="false">
                                  <i class="flaticon-speedometer"></i>
                                  <span>Oriented Program Daily </span>
                                </button>
                              </li>
                          </ul>
                    </div>
                </div><!--tabs-column-->
                <div class="col-lg-9 content-column">
                    <div class="tab-content wow fadeInRight" id="myTabContent">
                        <div class="tab-pane fade show active" id="home" role="tabpanel" aria-labelledby="home-tab">
                            <div class="row align-items-center">
                                <div class="col-lg-7 image-column">
                                    <div class="image-box">
                                        <figure class="image">
                                            <img src="images/resource/service-img.png" alt="">
                                        </figure>
                                    </div>
                                </div>
                                <div class="col-lg-5 content-column">
                                    <div class="inner-column">
                                        <h4 class="title text-white">Compare Energy</h4>
                                        <p class="text">Lorem ipsum dolor sit amet, consectetur adipisic incididunt ut labore et dolore magna aliqua. Ut en massa. Lorem ipsum dolor sit amet,to mod tempo magna aliqua. Ut enims ad minim veniam. Aenea cididunt ut labore et dolore magna</p>
                                        <ul>
                                            <li class="text">Compare Gas and Electricity</li>
                                            <li class="text">Business energy</li>
                                            <li class="text">Business electricity</li>
                                            <li class="text">Dual fuel tariffs</li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab-pane fade" id="profile" role="tabpanel" aria-labelledby="profile-tab">
                            <div class="row align-items-center">
                                <div class="col-lg-7 image-column">
                                    <div class="image-box">
                                        <figure class="image">
                                            <img src="images/resource/service-img.png" alt="">
                                        </figure>
                                    </div>
                                </div>
                                <div class="col-lg-5 content-column">
                                    <div class="inner-column">
                                        <h4 class="title text-white">Compare Energy</h4>
                                        <p class="text">Lorem ipsum dolor sit amet, consectetur adipisic incididunt ut labore et dolore magna aliqua. Ut en massa. Lorem ipsum dolor sit amet,to mod tempo magna aliqua. Ut enims ad minim veniam. Aenea cididunt ut labore et dolore magna</p>
                                        <ul>
                                            <li class="text">Compare Gas and Electricity</li>
                                            <li class="text">Business energy</li>
                                            <li class="text">Business electricity</li>
                                            <li class="text">Dual fuel tariffs</li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab-pane fade" id="contact" role="tabpanel" aria-labelledby="contact-tab">
                            <div class="row align-items-center">
                                <div class="col-lg-7 image-column">
                                    <div class="image-box">
                                        <figure class="image">
                                            <img src="images/resource/service-img.png" alt="">
                                        </figure>
                                    </div>
                                </div>
                                <div class="col-lg-5 content-column">
                                    <div class="inner-column">
                                        <h4 class="title text-white">Compare Energy</h4>
                                        <p class="text">Lorem ipsum dolor sit amet, consectetur adipisic incididunt ut labore et dolore magna aliqua. Ut en massa. Lorem ipsum dolor sit amet,to mod tempo magna aliqua. Ut enims ad minim veniam. Aenea cididunt ut labore et dolore magna</p>
                                        <ul>
                                            <li class="text">Compare Gas and Electricity</li>
                                            <li class="text">Business energy</li>
                                            <li class="text">Business electricity</li>
                                            <li class="text">Dual fuel tariffs</li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="tab-pane fade" id="contact2" role="tabpanel" aria-labelledby="contact2-tab">
                            <div class="row align-items-center">
                                <div class="col-lg-7 image-column">
                                    <div class="image-box">
                                        <figure class="image">
                                            <img src="images/resource/service-img.png" alt="">
                                        </figure>
                                    </div>
                                </div>
                                <div class="col-lg-5 content-column">
                                    <div class="inner-column">
                                        <h4 class="title text-white">Compare Energy</h4>
                                        <p class="text">Lorem ipsum dolor sit amet, consectetur adipisic incididunt ut labore et dolore magna aliqua. Ut en massa. Lorem ipsum dolor sit amet,to mod tempo magna aliqua. Ut enims ad minim veniam. Aenea cididunt ut labore et dolore magna</p>
                                        <ul>
                                            <li class="text">Compare Gas and Electricity</li>
                                            <li class="text">Business energy</li>
                                            <li class="text">Business electricity</li>
                                            <li class="text">Dual fuel tariffs</li>
                                        </ul>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- SERVICES SECTION END -->
    
    <!-- MEMBERSHIP  -->
    <section class="memebership-section">
        <div class="container pb-0">
            <div class="membership-content">
                <div class="memebership-content">
                    <span class="wow fadeInUp">We’re building Ultrafast Full Fibre Broadband</span>
                    <h2 class="wow fadeInUp" data-wow-delay="200ms">3 Month Free Full Fibre</h2>
                    <form class="wow fadeInUp" data-wow-delay="400ms">
                        <div class="input-field">
                            <input type="text" name="passcode" placeholder="Enter Your Postcode">
                            <i class="fa fa-map-marker-alt"></i>
                            <select class="js-example-basic-single" name="state">
                                <option value="AL">I Am a Home User</option>
                                <option value="WY">I Am a Home User</option>
                            </select>
                        </div>
                        <button>Let's Go</button>
                    </form>
                </div><!--memebership-content-->
            </div>
        </div>
    </section><!--memebership-section-->
    <!-- MEMBERSHIP END -->

    <!-- PRICES SECTION -->
    <section class="price-seciton">
        <div class="bg bg-pattern-v2"></div>
        <div class="container py-0">
            <div class="sec-title-v2 text-center wow fadeInUp">
                <i class="flaticon-wifi-1 text-white"></i>
                <span class="sub-title text">Full fibre speeds at</span>
                <h2>Affordable Prices</h2>
            </div><!--sec-title end-->
            <div class="outer-box">
                <div class="row">
                    <div class="col-lg-3 col-md-6 col-sm-6 price-column">
                        <div class="inner-column wow fadeInLeft">
                            <span class="text">Only Internet</span>
                            <h2 class="text-white">$26.99</h2>
                            <strong class="text">per month</strong>
                            <div class="icon-box">
                                <img src="images/icons/price1.png" alt="">
                            </div>
                            <ul>
                                <li class="text">Router included</li>
                                <li class="text">Free home install</li>
                                <li class="text">Free survey</li>
                            </ul>
                            <a href="page-contact.html" title="" class="theme-btn-v2 bg-dark text-white">Order Now</a>
                            <span class="text">75Mbps Download</span>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-sm-6 price-column">
                        <div class="inner-column wow fadeInLeft" data-wow-delay="200ms">
                            <span class="text">Only Internet</span>
                            <h2 class="text-white">$26.99</h2>
                            <strong class="text">per month</strong>
                            <div class="icon-box">
                                <img src="images/icons/price2.png" alt="">
                            </div>
                            <ul>
                                <li class="text">Router included</li>
                                <li class="text">Free home install</li>
                                <li class="text">Free survey</li>
                            </ul>
                            <a href="page-contact.html" title="" class="theme-btn-v2 bg-dark text-white">Order Now</a>
                            <span class="text">75Mbps Download</span>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-sm-6 price-column">
                        <div class="inner-column wow fadeInLeft" data-wow-delay="400ms">
                            <span class="text">Only Internet</span>
                            <h2 class="text-white">$26.99</h2>
                            <strong class="text">per month</strong>
                            <div class="icon-box">
                                <img src="images/icons/price3.png" alt="">
                            </div>
                            <ul>
                                <li class="text">Router included</li>
                                <li class="text">Free home install</li>
                                <li class="text">Free survey</li>
                            </ul>
                            <a href="page-contact.html" title="" class="theme-btn-v2 bg-dark text-white">Order Now</a>
                            <span class="text">75Mbps Download</span>
                        </div>
                    </div>
                    <div class="col-lg-3 col-md-6 col-sm-6 price-column">
                        <div class="inner-column wow fadeInLeft" data-wow-delay="600ms">
                            <span class="text">Only Internet</span>
                            <h2 class="text-white">$26.99</h2>
                            <strong class="text">per month</strong>
                            <div class="icon-box">
                                <img src="images/icons/price4.png" alt="">
                            </div>
                            <ul>
                                <li class="text">Router included</li>
                                <li class="text">Free home install</li>
                                <li class="text">Free survey</li>
                            </ul>
                            <a href="page-contact.html" title="" class="theme-btn-v2 bg-dark text-white">Order Now</a>
                            <span class="text">75Mbps Download</span>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- PRICES SECTION END -->

    <!-- FEATURES SECTION  -->
    <section class="features-section-v2 pb-0">
        <div class="container py-0">
            <div class="row align-items-center">
                <div class="col-lg-7 feature-column">
                    <div class="inner-column wow fadeInUp">
                        <div class="sec-title-v2">
                            <span class="sub-title border-shape text">Standard Fibre and Full Fibre</span>
                            <h2>Most Reliable Hub Yet </h2>
                        </div>
                        <p class="text">Lorem ipsum dolor sit amet, consectetur adipisicing elit,sed eius to mod incididunt ut labore et dolore magna aliqua. Ut enims ad minim veniam. magna aliqua. Ut enims ad minim veniam. Aenean massa.</p>
                        <div class="features-list">
                            <div class="row">
                                <div class="col-lg-6 col-md-6 col-sm-6">
                                    <div class="feature-box">
                                        <div class="icon-box">
                                            <i class="flaticon-secure-shield"></i>
                                        </div>
                                        <div class="content-info">
                                            <h6 class="text-white">Built for reliability</h6>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-6 col-sm-6">
                                    <div class="feature-box">
                                        <div class="icon-box">
                                            <i class="flaticon-wifi-1"></i>
                                        </div>
                                        <div class="content-info">
                                            <h6 class="text-white">Stronger Wi-Fi connection</h6>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-6 col-sm-6">
                                    <div class="feature-box">
                                        <div class="icon-box">
                                            <i class="flaticon-responsive"></i>
                                        </div>
                                        <div class="content-info">
                                            <h6 class="text-white">Multiple devices</h6>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-6 col-md-6 col-sm-6">
                                    <div class="feature-box">
                                        <div class="icon-box">
                                            <i class="flaticon-speedometer"></i>
                                        </div>
                                        <div class="content-info">
                                            <h6 class="text-white">Delivers great speeds</h6>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-lg-5 image-column">
                    <div class="image-box wow zoomIn">
                        <figure class="image">
                            <img src="images/resource/img1.png" alt="">
                        </figure>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- FEATURES SECTION END -->

    <!-- FEATURED SHOWS -->

    <section class="featured-show-section-v2">
        <div class="container pb-0">
            <div class="sec-title-v2 text-center wow fadeInUp">
                <i class="flaticon-wifi-1 text-white"></i>
                <span class="sub-title text">NOW SHOWING</span>
                <h2>Featured Showing</h2>
            </div><!--sec-title end-->
        </div>
        <div class="featured-shows-slider">
            <div class="swiper-container swiper1">
                <!-- Additional required wrapper -->
                <div class="swiper-wrapper">
                    <!-- Slides -->
                    <div class="swiper-slide">
                        <div class="featured-show-slide">
                            <div class="image-box">
                                <img src="images/resource/featured-img1.jpg" alt="">
                                <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="play-button swipebox"><img src="images/icons/play2.png" alt=""></a>
                                <div class="featured-caption">
                                    <h5 class="title">Joker the lady</h5>
                                    <span class="show-rating">
                                        <i class="fa fa-star"></i>
                                        4.5
                                    </span>
                                    <span class="show-duration">2022 / 2 h 30 min</span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="swiper-slide">
                        <div class="featured-show-slide">
                            <div class="image-box">
                                <img src="images/resource/featured-img2.jpg" alt="">
                                <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="play-button swipebox"><img src="images/icons/play2.png" alt=""></a>
                                <div class="featured-caption">
                                    <h5 class="title">Joker the lady</h5>
                                    <span class="show-rating">
                                        <i class="fa fa-star"></i>
                                        4.5
                                    </span>
                                    <span class="show-duration">2022 / 2 h 30 min</span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="swiper-slide">
                        <div class="featured-show-slide">
                            <div class="image-box">
                                <img src="images/resource/featured-img3.jpg" alt="">
                                <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="play-button swipebox"><img src="images/icons/play2.png" alt=""></a>
                                <div class="featured-caption">
                                    <h5 class="title">Joker the lady</h5>
                                    <span class="show-rating">
                                        <i class="fa fa-star"></i>
                                        4.5
                                    </span>
                                    <span class="show-duration">2022 / 2 h 30 min</span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="swiper-slide">
                        <div class="featured-show-slide">
                            <div class="image-box">
                                <img src="images/resource/featured-img1.jpg" alt="">
                                <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="play-button swipebox"><img src="images/icons/play2.png" alt=""></a>
                                <div class="featured-caption">
                                    <h5 class="title">Joker the lady</h5>
                                    <span class="show-rating">
                                        <i class="fa fa-star"></i>
                                        4.5
                                    </span>
                                    <span class="show-duration">2022 / 2 h 30 min</span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="swiper-slide">
                        <div class="featured-show-slide">
                            <div class="image-box">
                                <img src="images/resource/featured-img2.jpg" alt="">
                                <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="play-button swipebox"><img src="images/icons/play2.png" alt=""></a>
                                <div class="featured-caption">
                                    <h5 class="title">Joker the lady</h5>
                                    <span class="show-rating">
                                        <i class="fa fa-star"></i>
                                        4.5
                                    </span>
                                    <span class="show-duration">2022 / 2 h 30 min</span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="swiper-slide">
                        <div class="featured-show-slide">
                            <div class="image-box">
                                <img src="images/resource/featured-img3.jpg" alt="">
                                <a href="https://www.youtube.com/watch?v=-B7-Vcdlld8" title="" class="play-button swipebox"><img src="images/icons/play2.png" alt=""></a>
                                <div class="featured-caption">
                                    <h5 class="title">Joker the lady</h5>
                                    <span class="show-rating">
                                        <i class="fa fa-star"></i>
                                        4.5
                                    </span>
                                    <span class="show-duration">2022 / 2 h 30 min</span>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="slider__pagination"></div>
            </div>
        </div>
    </section>

    <!-- FEATURED SHOWS END -->

    <!-- TESTIMONIAL / FUN FACTS SECTION -->

    <section class="testi-funcfact-section">

        <div class="testimonial-section-v2 pt-0">
            <div class="container">
                <div class="sec-title-v2 wow fadeInUp">
                    <span class="sub-title border-shape text">Client’s Reviews</span>
                    <h2>What Expert Says...</h2>
                </div>
                <div class="testimonial-v2">
                    <div class="testimonail-slider wow fadeInUp">
                        <div class="testimonial-slide">
                            <div class="row align-items-center">
                                <div class="col-lg-7 testimonial-column">
                                    <div class="inner-column">
                                        <div class="icon-box">
                                            <img src="images/icons/quotes-white.png" alt="">
                                        </div>
                                        <div class="content-info">
                                            <p class="text">We help our clients from the definition of their strategy to the realization of their digital ecosystem.  At the heart of our approach is the constant search  for the juncture between aesthetic.</p>
                                            <h4 class="text-white">Edison Cavani</h4>
                                            <span>Product Management </span>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-5 testimonial-image-column">
                                    <div class="image-box">
                                        <figure class="image">
                                            <img src="images/resource/testi-img1.jpg" alt="">
                                        </figure>
                                    </div>
                                </div><!--testimonial-image-column-->
                            </div>
                        </div><!--testimonial-slide-->
                        <div class="testimonial-slide">
                            <div class="row align-items-center">
                                <div class="col-lg-7 testimonial-column">
                                    <div class="inner-column">
                                        <div class="icon-box">
                                            <img src="images/icons/quotes-white.png" alt="">
                                        </div>
                                        <div class="content-info">
                                            <p class="text">We help our clients from the definition of their strategy to the realization of their digital ecosystem.  At the heart of our approach is the constant search  for the juncture between aesthetic.</p>
                                            <h4 class="text-white">Edison Cavani</h4>
                                            <span>Product Management </span>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-5 testimonial-image-column">
                                    <div class="image-box">
                                        <figure class="image">
                                            <img src="images/resource/testi-img1.jpg" alt="">
                                        </figure>
                                    </div>
                                </div><!--testimonial-image-column-->
                            </div>
                        </div><!--testimonial-slide-->
                        <div class="testimonial-slide">
                            <div class="row align-items-center">
                                <div class="col-lg-7 testimonial-column">
                                    <div class="inner-column">
                                        <div class="icon-box">
                                            <img src="images/icons/quotes-white.png" alt="">
                                        </div>
                                        <div class="content-info">
                                            <p class="text">We help our clients from the definition of their strategy to the realization of their digital ecosystem.  At the heart of our approach is the constant search  for the juncture between aesthetic.</p>
                                            <h4 class="text-white">Edison Cavani</h4>
                                            <span>Product Management </span>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-5 testimonial-image-column">
                                    <div class="image-box">
                                        <figure class="image">
                                            <img src="images/resource/testi-img1.jpg" alt="">
                                        </figure>
                                    </div>
                                </div><!--testimonial-image-column-->
                            </div>
                        </div><!--testimonial-slide-->
                        <div class="testimonial-slide">
                            <div class="row align-items-center">
                                <div class="col-lg-7 testimonial-column">
                                    <div class="inner-column">
                                        <div class="icon-box">
                                            <img src="images/icons/quotes-white.png" alt="">
                                        </div>
                                        <div class="content-info">
                                            <p class="text">We help our clients from the definition of their strategy to the realization of their digital ecosystem.  At the heart of our approach is the constant search  for the juncture between aesthetic.</p>
                                            <h4 class="text-white">Edison Cavani</h4>
                                            <span>Product Management </span>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-5 testimonial-image-column">
                                    <div class="image-box">
                                        <figure class="image">
                                            <img src="images/resource/testi-img1.jpg" alt="">
                                        </figure>
                                    </div>
                                </div><!--testimonial-image-column-->
                            </div>
                        </div><!--testimonial-slide-->
                    </div><!--testimonail-slider-->
                    <div class="testimonial-thumbs-slider wow fadeInRight">
                        <div class="testi-thumb">
                            <img src="images/resource/thumb1.jpg" alt="">
                        </div>
                        <div class="testi-thumb">
                            <img src="images/resource/thumb2.jpg" alt="">
                        </div>
                        <div class="testi-thumb">
                            <img src="images/resource/thumb3.jpg" alt="">
                        </div>
                        <div class="testi-thumb">
                            <img src="images/resource/thumb4.jpg" alt="">
                        </div>
                        <div class="testi-thumb">
                            <img src="images/resource/thumb1.jpg" alt="">
                        </div>
                        <div class="testi-thumb">
                            <img src="images/resource/thumb2.jpg" alt="">
                        </div>
                        <div class="testi-thumb">
                            <img src="images/resource/thumb3.jpg" alt="">
                        </div>
                        <div class="testi-thumb">
                            <img src="images/resource/thumb4.jpg" alt="">
                        </div>
                    </div><!--testimonial-thumbs-slider-->
                </div>
            </div>
        </div><!--testimonial-section-v2-->

        <div class="funfacts-section">
            <div class="container">
                <div class="row">
                    <div class="col-lg-12 image-column">
                        <div class="inner-box wow fadeInUp">
                            <div class="image-box">
                                <figure class="image">
                                    <img src="images/resource/img-box1.jpg" alt="">
                                </figure>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-4 col-sm-6 funcfact-column">
                        <div class="inner-column wow fadeInLeft">
                            <h2 class="title">28.6m</h2>
                            <p>Homes and businesses that can get fibre broadband speeds.</p>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-4 col-sm-6 funcfact-column">
                        <div class="inner-column wow fadeInUp" data-wow-delay="200ms">
                            <h2 class="title">250+</h2>
                            <p>WorldWide TV Channels broadcasting on the internet for free.</p>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-4 col-sm-6 funcfact-column">
                        <div class="inner-column wow fadeInRight" data-wow-delay="400ms">
                            <h2 class="title">50mbps</h2>
                            <p>fast your internet connection is with our easy-to-use speed test. </p>
                        </div>
                    </div>
                </div>
            </div>
        </div>

    </section>

    <!-- TESTIMONIAL / FUN FACTS SECTION END-->
    
    <!-- NEWS SECTION -->
    <section class="news-section-v2 pb-0">
        <div class="container py-0">
            <div class="sec-title-v2 text-center wow fadeInUp">
                <i class="flaticon-wifi-1 text-white"></i>
                <span class="sub-title text">News &amp; Updates</span>
                <h2>Recent Articles</h2>
            </div><!--sec-title end-->
            <div class="outer-box">
                <div class="row">
                    <div class="col-lg-4 col-md-6 news-block">
                        <div class="inner-column wow fadeInLeft">
                            <div class="image-box">
                                <figure class="image">
                                    <img src="images/resource/blog1.jpg" alt="">
                                </figure>
                                <div class="blog-posted-date">
                                    <h2>12</h2>
                                    <span>Dec, 23</span>
                                </div>
                            </div>
                            <div class="content-info">
                                <h4 class="title"><a href="page-news-details.html" title="">Putting All Safe Parenting Tools in One App</a></h4>
                                <div class="user-box">
                                    <div class="user-box-img">
                                        <img src="images/resource/user.png" alt="">
                                    </div>
                                    <div class="user-box-info">
                                        <h4><a href="page-news-details.html" title="">Jassica Thomas</a></h4>
                                        <span>2 COMMENTS</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-6 news-block">
                        <div class="inner-column wow fadeInUp" data-wow-delay="200ms">
                            <div class="image-box">
                                <figure class="image">
                                    <img src="images/resource/blog3.jpg" alt="">
                                </figure>
                                <div class="blog-posted-date">
                                    <h2>12</h2>
                                    <span>Dec, 23</span>
                                </div>
                            </div>
                            <div class="content-info">
                                <h4 class="title"><a href="page-news-details.html" title="">Putting All Safe Parenting Tools in One App</a></h4>
                                <div class="user-box">
                                    <div class="user-box-img">
                                        <img src="images/resource/user.png" alt="">
                                    </div>
                                    <div class="user-box-info">
                                        <h4><a href="page-news-details.html" title="">Jassica Thomas</a></h4>
                                        <span>2 COMMENTS</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-6 news-block">
                        <div class="inner-column wow fadeInRight" data-wow-delay="400ms">
                            <div class="image-box">
                                <figure class="image">
                                    <img src="images/resource/blog2.jpg" alt="">
                                </figure>
                                <div class="blog-posted-date">
                                    <h2>12</h2>
                                    <span>Dec, 23</span>
                                </div>
                            </div>
                            <div class="content-info">
                                <h4 class="title"><a href="page-news-details.html" title="">Putting All Safe Parenting Tools in One App</a></h4>
                                <div class="user-box">
                                    <div class="user-box-img">
                                        <img src="images/resource/user.png" alt="">
                                    </div>
                                    <div class="user-box-info">
                                        <h4><a href="page-news-details.html" title="">Jassica Thomas</a></h4>
                                        <span>2 COMMENTS</span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="full-button text-center wow fadeInUp">
                    <a href="news-grid.html" title="" class="theme-btn-v2 bg-btn bg-dark text-white">view all news</a>
                </div>
            </div>
        </div>
    </section>
    <!-- NEWS SECTION END -->

    <!-- PARTNERS SECTION  -->

    <section class="partners-section">
        <div class="container pb-0">
            <div class="outer-box">
                <h3 class="wow fadeInUp text-white">Search by Broadband Provider</h3>
                <div class="row">
                    <div class="col-lg-2 col-md-2 col-sm-4 col-6 partner-column">
                        <div class="image-box wow fadeIn">
                            <figure class="image">
                                <img src="images/resource/partner1.png" alt="">
                            </figure>
                        </div>
                    </div>
                    <div class="col-lg-2 col-md-2 col-sm-4 col-6 partner-column">
                        <div class="image-box wow fadeIn" data-wow-delay="100ms">
                            <figure class="image">
                                <img src="images/resource/partner2.png" alt="">
                            </figure>
                        </div>
                    </div>
                    <div class="col-lg-2 col-md-2 col-sm-4 col-6 partner-column">
                        <div class="image-box wow fadeIn" data-wow-delay="200ms">
                            <figure class="image">
                                <img src="images/resource/partner3.png" alt="">
                            </figure>
                        </div>
                    </div>
                    <div class="col-lg-2 col-md-2 col-sm-4 col-6 partner-column">
                        <div class="image-box wow fadeIn" data-wow-delay="300ms">
                            <figure class="image">
                                <img src="images/resource/partner4.png" alt="">
                            </figure>
                        </div>
                    </div>
                    <div class="col-lg-2 col-md-2 col-sm-4 col-6 partner-column">
                        <div class="image-box wow fadeIn" data-wow-delay="400ms">
                            <figure class="image">
                                <img src="images/resource/partner5.png" alt="">
                            </figure>
                        </div>
                    </div>
                    <div class="col-lg-2 col-md-2 col-sm-4 col-6 partner-column">
                        <div class="image-box wow fadeIn" data-wow-delay="500ms">
                            <figure class="image">
                                <img src="images/resource/partner6.png" alt="">
                            </figure>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>

    <!-- PARTNERS SECTION END  -->

    <!--  FOOTER -->

    <footer class="footer-v2">  
        <div class="footer-upper">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-8 text-column">
                        <h4>Our award-winning, customer support is available 7 days a week</h4>
                    </div>
                    <div class="col-lg-4 contact-info">
                        <div class="inner-box">
                            <div class="icon-box">
                                <img src="images/icons/phone.png" alt="">
                            </div>
                            <div class="box-info">
                                <h5>Phone.  +88(9800) 6802</h5>
                            </div>
                        </div>
                    </div><!--contact-info-->
                </div>
            </div>
        </div><!--footer-upper-->
        <div class="container">
            <div class="widgets-sections row">
                <div class="col-lg-4 col-md-6 footer-column">
                    <div class="widget widget-about wow fadeInLeft">
                        <img src="images/logo-v2.png" alt="">
                        <p>Really needn't be a hassle. All it takes is 10 minutes and we'll do the rest</p>
                        <h5>OPENING HOURS</h5>
                        <span>Mon - Sat (8:00 - 6:00)</span>
                        <span>Sunday - Closed </span>
                    </div><!--widget-about-->
                </div>
                <div class="col-lg-4 col-md-6 footer-column">
                    <div class="widget widget-links wow fadeInUp" data-wow-delay="200ms">
                        <h4 class="widget-title">Useful Links</h4>
                        <div class="row">
                            <div class="col-lg-6 col-md-6 col-sm-6 col-6">
                                <ul class="user-links">
                                    <li><a href="#" title="">About</a></li>
                                    <li><a href="#" title="">Contact</a></li>
                                    <li><a href="#" title="">Our Packages</a></li>
                                    <li><a href="#" title="">Services</a></li>
                                    <li><a href="#" title="">Gallery</a></li>
                                </ul>
                            </div>
                            <div class="col-lg-6 col-md-6 col-sm-6 col-6">
                                <ul class="user-links">
                                    <li><a href="#" title="">Meet the Team</a></li>
                                    <li><a href="#" title="">Sitemap</a></li>
                                    <li><a href="#" title="">Reprint Policy</a></li>
                                    <li><a href="#" title="">Videos</a></li>
                                    <li><a href="#" title="">Topics</a></li>
                                </ul>
                            </div>
                        </div>
                    </div><!--widget-links end-->
                </div>
                <div class="col-lg-4 col-md-12 footer-column">
                    <div class="widget widget-newsletter wow fadeInRight" data-wow-delay="400ms">
                        <h4 class="widget-title">Newsletter</h4>
                        <p>Our expertise, as well as our passion for web design, sets us apart from other agencies. </p>
                        <form>
                            <input type="text" name="email" placeholder="Enter your email address...">
                            <button type="submit"><i class="lnr-icon-arrow-right"></i></button>
                        </form>
                    </div><!--widget-newsletter-->
                </div>
            </div>
        </div>
        <div class="footer-bottom">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-md-4 copyright-text text-center text-lg-start">
                        <p>Copyright © reserved by . koresolution.</p>
                    </div>
                    <div class="col-md-4 social-column text-center">
                        <ul class="social-links">
                            <li><a href="#" title=""><i class="fab fa-facebook-square"></i></a></li>
                            <li><a href="#" title=""><i class="fab fa-google-plus-g"></i></a></li>
                            <li><a href="#" title=""><i class="fa fa-x"></i></a></li>
                        </ul>
                    </div>
                    <div class="col-md-4 links-column text-center text-lg-end">
                        <ul class="other-links">
                            <li><a href="#" title="">About</a></li>
                            <li><a href="#" title="">Terms</a></li>
                            <li><a href="#" title="">privacy policy</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </footer>

    <!--  FOOTER END -->

</div><!-- End Page Wrapper -->

<!-- Scroll To Top -->
<div class="scroll-to-top scroll-to-target clr-v2" data-target="html"><span class="fa fa-angle-up"></span></div>

<script data-cfasync="false" src="../../cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.js"></script><script src="js/jquery.js"></script> 
<script src="js/jquery-migrate-1.4.1.min.js"></script>
<script src="js/slick.min.js"></script>
<script src="js/popper.min.js"></script>
<script src="js/bootstrap.min.js"></script>
<script src="js/slick-animation.min.js"></script>
<script src="js/wow.js"></script>
<script src="js/select2.min.js"></script>
<script src="js/swiper-bundle.min.js"></script>
<script src="js/jquery.swipebox.min.js"></script>
<script src="js/script.js"></script>



<script id="custom-js" src="js/code_editor_scripts.js?dEEYHyo3"></script></body><!-- Mirrored from html.kodesolution.com/2023/satnet-html/index-4-dark.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:18 GMT --></html>